DefaultAugmentedOneSignalPlatform class

Default implementation = throws UnsupportedError everywhere

Implemented types

Properties

clickNotificationStream Stream<AugmentedNotification>
no setteroverride
foregroundNotificationStream Stream<AugmentedNotification>
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addTag(String key, String value) Future<void>
override
addTags(Map<String, String> tags) Future<void>
override
addUserEmail(String email) Future<void>
override
hasPushPermission() Future<bool>
override
init({required String apiKey}) Future<void>
override
login(String userId) Future<void>
override
logout() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
permissionChangeStream() Stream<bool>
override
removeTag(String key) Future<void>
override
removeTags(List<String> keys) Future<void>
override
removeUserEmail(String email) Future<void>
override
requestPushPermission(bool fallbackToSettings) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited