AugmentedOneSignalPlatform class abstract
- Implementers
Constructors
Properties
-
clickNotificationStream
→ Stream<
AugmentedNotification> -
no setter
-
foregroundNotificationStream
→ Stream<
AugmentedNotification> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTag(
String key, String value) → Future< void> -
addTags(
Map< String, String> tags) → Future<void> -
addUserEmail(
String email) → Future< void> -
hasPushPermission(
) → Future< bool> -
init(
{required String apiKey}) → Future< void> -
login(
String userId) → Future< void> -
logout(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
permissionChangeStream(
) → Stream< bool> -
removeTag(
String key) → Future< void> -
removeTags(
List< String> keys) → Future<void> -
removeUserEmail(
String email) → Future< void> -
requestPushPermission(
bool fallbackToSettings) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ AugmentedOneSignalPlatform
-
getter/setter pair